#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_COMPLEMENT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_COMPLEMENT_HPP_INCLUDED

#include <nt2/operator/include/functions/scalar/complement.hpp>

#endif
